==> CloudManagerStandardAWS_v2.0.0.tar.gz: CloudManagerStandardAWS_v2.0.0/cloud_manager_standard-2.0.0/scripts/cloud_install_main.sh <==
#!/bin/bash

#Copyright (C) 2013 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or 
#Modify it under the terms of the GNU General Public License 
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful, 
#but WITHOUT ANY WARRANTY; without even the implied warranty of 
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
#GNU General Public License for more details

SCRIPT_DIR=$(cd $(dirname $0);pwd)

. ${SCRIPT_DIR}/scripts/cloud_install_function.sh

set_hinemos_home

. ${HINEMOS_HOME}/hinemos.cfg
. ${SCRIPT_DIR}/scripts/conf.sh

check_version ${DEPENDENCY_VER_FILE} ${REQUIRED_VERSION} ${DEPENDENCY_MODULE_NAME}

echo ----- ${OPTION_PACKAGE_NAME} start ----------

install_settings ${SCRIPT_DIR} ${HINEMOS_HOME}
install_libraries ${LIBDIR} ${PLUGINS_DIR} ${PLUGINS_IN_PACKAGE_DIR} ${INSTALL_USER} ${INSTALL_GROUP} "${INSTALL_LIBRARIES}"
regist_persistence ${LIBDIR} ${PERSISTENCE_XML_PATH} "${ENTITY_JARS}" "${XML_POST_JAR_POSITION}" "${ORM_XML_PATHS}" "${XML_POST_ORM_POSITION}"

echo ${VERSION_NUMBER} | cat > ${HINEMOS_HOME}/${VERSION_FILE_NAME} 
chown ${INSTALL_USER}:${INSTALL_GROUP} ${HINEMOS_HOME}/${VERSION_FILE_NAME}

echo ----- ${OPTION_PACKAGE_NAME} end   ----------
echo
echo ----- db start  ------------

unset PGPASSWORD
if [ -n "${TABLE_SCRIPT}" ]; then
	db_manipulate ${PG_HOME} ${PG_USER} "${TABLE_SCRIPT}"
fi
if [ -n "${DATA_SCRIPT}" ]; then
	db_manipulate ${PG_HOME} ${PG_USER} "${DATA_SCRIPT}"
fi

echo ----- db end   -------------
echo
echo install succeeded !
exit 0

==> CloudManagerStandardAWS_v2.0.1.tar.gz: CloudManagerStandardAWS_v2.0.1/cloud_manager_standard-2.0.1/scripts/cloud_install_main.sh <==
#!/bin/bash

#Copyright (C) 2013 NTT DATA Corporation
#
#This program is free software; you can redistribute it and/or 
#Modify it under the terms of the GNU General Public License 
#as published by the Free Software Foundation, version 2.
#
#This program is distributed in the hope that it will be useful, 
#but WITHOUT ANY WARRANTY; without even the implied warranty of 
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
#GNU General Public License for more details

SCRIPT_DIR=$(cd $(dirname $0);pwd)

. ${SCRIPT_DIR}/scripts/cloud_install_function.sh

set_hinemos_home

. ${HINEMOS_HOME}/hinemos.cfg
. ${SCRIPT_DIR}/scripts/conf.sh

check_version ${DEPENDENCY_VER_FILE} ${REQUIRED_VERSION} ${DEPENDENCY_MODULE_NAME}

echo ----- ${OPTION_PACKAGE_NAME} start ----------

install_settings ${SCRIPT_DIR} ${HINEMOS_HOME}
install_libraries ${LIBDIR} ${PLUGINS_DIR} ${PLUGINS_IN_PACKAGE_DIR} ${INSTALL_USER} ${INSTALL_GROUP} "${INSTALL_LIBRARIES}"
regist_persistence ${LIBDIR} ${PERSISTENCE_XML_PATH} "${ENTITY_JARS}" "${XML_POST_JAR_POSITION}" "${ORM_XML_PATHS}" "${XML_POST_ORM_POSITION}"

echo ${VERSION_NUMBER} | cat > ${HINEMOS_HOME}/${VERSION_FILE_NAME} 
chown ${INSTALL_USER}:${INSTALL_GROUP} ${HINEMOS_HOME}/${VERSION_FILE_NAME}

if [ -f "${SCRIPT_DIR}/scripts/post_setting.sh" ]; then
	. ${SCRIPT_DIR}/scripts/post_setting.sh
fi

echo ----- ${OPTION_PACKAGE_NAME} end   ----------
echo
echo ----- db start  ------------

unset PGPASSWORD
if [ -n "${TABLE_SCRIPT}" ]; then
	db_manipulate ${PG_HOME} ${PG_USER} "${TABLE_SCRIPT}"
fi
if [ -n "${DATA_SCRIPT}" ]; then
	db_manipulate ${PG_HOME} ${PG_USER} "${DATA_SCRIPT}"
fi
if [ -f "${SCRIPT_DIR}/scripts/post_db_setting.sh" ]; then
	. ${SCRIPT_DIR}/scripts/post_db_setting.sh
fi

echo ----- db end   -------------
echo
echo install succeeded !
exit 0
